@@ -1,21 +1,20 @@
 import os
 import textwrap
-
+from abc import ABC
 from logging import debug
+from pathlib import Path
+from types import SimpleNamespace
+
 from cli_ui import debug as verbose
 from cli_ui import fatal
-
-import yaml
-from pathlib import Path
 from mergedeep import merge
+from yamlpath.common import Parsers
+from yamlpath.wrappers import ConsolePrinter
+
 from gitlabform import EXIT_INVALID_INPUT
 
 
-class ConfigurationCore:
-
-    config = None
-    config_dir = None
-
+class ConfigurationCore(ABC):
     def __init__(self, config_path=None, config_string=None):
 
         if config_path and config_string:
@@ -23,35 +22,17 @@ class ConfigurationCore:
                 "Please initialize with either config_path or config_string, not both.",
                 exit_code=EXIT_INVALID_INPUT,
             )
-
         try:
             if config_string:
-                verbose("Reading config from provided string.")
-                self.config = yaml.safe_load(textwrap.dedent(config_string))
+                self.config = self._parse_yaml(config_string, config_string=True)
                 self.config_dir = "."
             else:  # maybe config_path
-                if "APP_HOME" in os.environ:
-                    # using this env var should be considered unofficial, we need this temporarily
-                    # for backwards compatibility. support for it may be removed without notice, do not use it!
-                    config_path = os.path.join(os.environ["APP_HOME"], "config.yml")
-                elif not config_path:
-                    # this case is only meant for using gitlabform as a library
-                    config_path = os.path.join(
-                        str(Path.home()), ".gitlabform", "config.yml"
-                    )
-                elif config_path in [os.path.join(".", "config.yml"), "config.yml"]:
-                    # provided points to config.yml in the app current working dir
-                    config_path = os.path.join(os.getcwd(), "config.yml")
-
-                verbose(f"Reading config from file: {config_path}")
-
-                with open(config_path, "r") as ymlfile:
-                    self.config = yaml.safe_load(ymlfile)
-                    debug("Config parsed successfully as YAML.")
-
-                # we need config path for accessing files for relative paths
+                config_path = self._get_config_path(config_path)
+                self.config = self._parse_yaml(config_path, config_string=False)
                 self.config_dir = os.path.dirname(config_path)
 
+                # below checks are only needed in the non-test mode, when the config is read from file
+
                 if self.config.get("example_config"):
                     fatal(
                         "Example config detected, aborting.\n"
@@ -79,6 +60,53 @@ class ConfigurationCore:
         except Exception as e:
             raise ConfigInvalidException(e)
 
+    @staticmethod
+    def _get_config_path(config_path):
+
+        if "APP_HOME" in os.environ:
+            # using this env var should be considered unofficial, we need this temporarily
+            # for backwards compatibility. support for it may be removed without notice, do not use it!
+            config_path = os.path.join(os.environ["APP_HOME"], "config.yml")
+        elif not config_path:
+            # this case is only meant for using gitlabform as a library
+            config_path = os.path.join(str(Path.home()), ".gitlabform", "config.yml")
+        elif config_path in [os.path.join(".", "config.yml"), "config.yml"]:
+            # provided points to config.yml in the app current working dir
+            config_path = os.path.join(os.getcwd(), "config.yml")
+
+        return config_path
+
+    @staticmethod
+    def _parse_yaml(source: str, config_string: bool):
+
+        logging_args = SimpleNamespace(quiet=False, verbose=False, debug=False)
+        log = ConsolePrinter(logging_args)
+
+        yaml = Parsers.get_yaml_editor()
+
+        # for better backward compatibility with PyYAML (that supports only YAML 1.1) used in the previous
+        # GitLabForm versions, let's force ruamel.yaml to use YAML version 1.1 by default too
+        yaml.version = (1, 1)
+
+        if config_string:
+            config_string = textwrap.dedent(source)
+            verbose("Reading config from the provided string.")
+            (yaml_data, doc_loaded) = Parsers.get_yaml_data(
+                yaml, log, config_string, literal=True
+            )
+        else:
+            config_path = source
+            verbose(f"Reading config from file: {config_path}")
+            (yaml_data, doc_loaded) = Parsers.get_yaml_data(yaml, log, config_path)
+
+        if doc_loaded:
+            debug("Config parsed successfully as YAML.")
+        else:
+            # an error message has already been printed via ConsolePrinter
+            exit(EXIT_INVALID_INPUT)
+
+        return yaml_data
+
     def get(self, path, default=None):
         """
         :param path: "path" to given element in YAML file, for example for:
@@ -114,18 +142,10 @@ class ConfigurationCore:
         return current
 
     def get_group_config(self, group) -> dict:
-        """
-        :param group: group/subgroup
-        :return: literal configuration for this group/subgroup or empty dict if not defined
-        """
-        return self.get(f"projects_and_groups|{group}/*", {})
+        pass
 
     def get_project_config(self, group_and_project) -> dict:
-        """
-        :param group_and_project: 'group/project'
-        :return: literal configuration for this project or empty dict if not defined
-        """
-        return self.get(f"projects_and_groups|{group_and_project}", {})
+        pass
 
     def get_common_config(self) -> dict:
         """
@@ -134,33 +154,13 @@ class ConfigurationCore:
         return self.get("projects_and_groups|*", {})
 
     def is_project_skipped(self, project) -> bool:
-        """
-        :return: if project is defined in the key with projects to skip
-        """
-        return self.is_skipped(project, self.get("skip_projects", []))
+        pass
 
     def is_group_skipped(self, group) -> bool:
-        """
-        :return: if group is defined in the key with groups to skip
-        """
-        return self.is_skipped(group, self.get("skip_groups", []))
+        pass
 
     def is_skipped(self, an_array: list, item: str) -> bool:
-        """
-        :return: if item is defined in the list to be skipped
-        """
-        for list_element in an_array:
-            if list_element == item:
-                return True
-
-            if (
-                list_element.endswith("/*")
-                and item.startswith(list_element[:-2])
-                and len(item) >= len(list_element[:-2])
-            ):
-                return True
-
-        return False
+        pass
 
     @staticmethod
     def merge_configs(more_general_config, more_specific_config) -> dict:
