@@ -1,18 +1,18 @@
 import json
+import os
 from logging import debug
-from cli_ui import debug as verbose
+from urllib import parse
 
 import pkg_resources
 import requests
-import os
 
 # noinspection PyPackageRequirements
 import urllib3
+from cli_ui import debug as verbose
+from requests.adapters import HTTPAdapter
 
 # noinspection PyPackageRequirements
 from urllib3.util.retry import Retry
-from urllib import parse
-from requests.adapters import HTTPAdapter
 
 from gitlabform.configuration import Configuration
 
@@ -225,8 +225,9 @@ class GitLabCore:
                 raise UnexpectedResponseException(
                     f"Request url='{url}', method={method}, {data_output} failed -"
                     f" expected code(s) {str(expected_codes)},"
-                    f" got code {response.status_code} & body: '{response.content}'",
+                    f" got code {response.status_code} & body: '{response.text}'",
                     response.status_code,
+                    response.text,
                 )
 
         debug("response json=%s" % json.dumps(response.json(), sort_keys=True))
@@ -279,9 +280,10 @@ class InvalidParametersException(Exception):
 
 
 class UnexpectedResponseException(Exception):
-    def __init__(self, message, status_code):
-        self.message = message
-        self.status_code = status_code
+    def __init__(self, message: str, response_status_code: int, response_text: str):
+        self.message: str = message
+        self.response_status_code: int = response_status_code
+        self.response_text: str = response_text
 
     def __str__(self):
         return self.message
