@@ -63,10 +63,11 @@ class GitLabGroups(GitLabCore):
         result = self._make_requests_to_api("groups?all_available=true", paginated=True)
         return sorted(map(lambda x: x["full_path"], result))
 
-    def get_projects(self, group, include_archived=False):
+    def get_projects(self, group, include_archived=False, only_names=True):
         """
         :param group: group name
         :param include_archived: set to True if archived projects should also be returned
+        :param only_names: set to False to get the whole project objects
         :return: sorted list of strings "group/project_name". Note that only projects from "group" namespace are
                  returned, so if "group" (= members of this group) is also a member of some projects, they won't be
                  returned here.
@@ -85,15 +86,24 @@ class GitLabGroups(GitLabCore):
         except NotFoundException:
             projects = []
 
-        all_project_and_groups = sorted(
-            map(lambda x: x["path_with_namespace"], projects)
-        )
-
         project_and_groups_in_group_namespace = [
-            x for x in all_project_and_groups if x.startswith(group + "/")
+            project
+            for project in projects
+            if project["path_with_namespace"].startswith(group + "/")
         ]
 
-        return project_and_groups_in_group_namespace
+        if only_names:
+            return sorted(
+                map(
+                    lambda x: x["path_with_namespace"],
+                    project_and_groups_in_group_namespace,
+                )
+            )
+        else:
+            return sorted(
+                project_and_groups_in_group_namespace,
+                key=lambda x: x["path_with_namespace"],
+            )
 
     def get_group_settings(self, project_and_group_name):
         try:
