@@ -11,27 +11,23 @@ from gitlabform.gitlab.core import (
 class GitLabProjects(GitLabCore):
     def get_project_case_insensitive(self, some_string):
 
-        # maybe "some_string" is the project's path
+        # maybe "foo/bar" is some project's path
 
         try:
+            # try with exact case
             return self.get_project(some_string)
         except NotFoundException:
 
-            # try searching by name - maybe "some_string" is project's name
-            # or path, but case insensitive
-
+            # try case insensitive
             projects = self._make_requests_to_api(
                 f"projects?search=%s&simple=true",
-                some_string,
+                some_string.lower(),
                 method="GET",
             )
             for project in projects:
-                if (
-                    project["path"].lower() == some_string.lower()
-                    or project["name"].lower() == some_string.lower()
-                ):
+                if project["path_with_namespace"].lower() == some_string.lower():
                     return project
-            raise NotFoundException
+            raise NotFoundException(f"Project with path '{some_string}' not found.")
 
     def create_project(
         self,
@@ -115,8 +111,8 @@ class GitLabProjects(GitLabCore):
 
     def get_all_projects(self, include_archived=False):
         """
-        :param group: group name
-        :return: sorted list of ALL projects you have access to, strings "group/project_name"
+        :param include_archived: if the archived projects should be returned too
+        :return: sorted list of ALL projects you have access to, strings like: "group/project_name"
         """
         try:
             # there are 3 states of the "archived" flag: true, false, undefined
@@ -228,9 +224,10 @@ class GitLabProjects(GitLabCore):
 
     def get_project_push_rules(self, project_and_group_name: str):
         try:
-            return self._make_requests_to_api(
-                "projects/%s/push_rule", project_and_group_name
-            )
+            # for this endpoint GitLab fails if project name contains ".", so lets use pid instead
+            pid: str = self._get_project_id(project_and_group_name)
+
+            return self._make_requests_to_api("projects/%s/push_rule", pid)
         except NotFoundException:
             return dict()
 
@@ -430,7 +427,7 @@ class GitLabProjects(GitLabCore):
         # it will return {group_name: {...api info about group_name...}, ...}
         groups = {}
         for group in project_info["shared_with_groups"]:
-            groups[group["group_name"]] = group
+            groups[group["group_full_path"]] = group
 
         return groups
 
